==> icebear_v1_4_1.tar: client/help/basics/index.php <==
<?php /**
Application-specific homepage help should not go in this file.
Instead, add it into extensions.php in this directory.
*/?><?php
include_once($_SERVER['DOCUMENT_ROOT'].'/client/help/_common/helphead.php');
?>
<h1>IceBear help</h1>

<p>Here are some basic details to help you find your way around IceBear.</p>
<p>Click the links at left for more information about a particular section.</p>

<h2>Logging in</h2>
<p>To use IceBear, you need to have an account. Ask your administrator to create one for you.</p>
<p>Log in with the username and password provided to you.</p>
<h2>Logging out</h2>
<p>To log out of IceBear, click the main menu icon at the top right of the page, then click "Log out [your username]" at the top left of the menu.</p>
<h2>Page header</h2>
<p>The page header contains a number of useful tools.</p>
<figure>
	<img alt="Header bar" src="headerbar.png" />
	<figcaption>The page header.</figcaption>
</figure>

<h3>Navigation breadcrumbs</h3> 
<p>On the left, there may be one or more buttons linking to useful pages. For example, when you view a project, you will see 
a link to the homepage and to a list of all projects.</p>
<h3>Find by barcode</h3>
<p>Type in this box to find items by their barcode. IceBear will suggest items as you type; you can use the up and down arrow
keys to move through the suggestions. press Enter to select the currently-highlighted suggestion.</p>
<p>If you have a barcode scanner, you can scan barcodes directly into this box.</p>
<h3>Main menu</h3>
<p>Click the main menu button at top right to open the menu. You will see something like this:</p>
<figure>
	<img alt="Main menu" src="mainmenu.png" />
	<figcaption>IceBear's main menu.</figcaption>
</figure>

<p>The exact options will depend on the application and on your permissions. Click any item to go there.</p>
<h3>Configuration</h3>
<p>Some pages, such as the homepage, can be configured to suit the way you work. These pages will have a gear wheel button 
next to the main menu button. Click this button to configure the page.</p>

<?php
include_once($_SERVER['DOCUMENT_ROOT'].'/client/help/_common/helpfoot.php');
?>

==> icebear_v1_12_0.tar: client/help/basics/index.php <==
<?php /**
Application-specific homepage help should not go in this file.
Instead, add it into extensions.php in this directory.
*/?><?php
include_once(dirname(__DIR__,3).'/client/help/_common/helphead.php');
?>
<h1>IceBear help</h1>

<p>Here are some basic details to help you find your way around IceBear.</p>
<p>Click the links at left for more information about a particular section.</p>

<h2>Logging in</h2>
<p>To use IceBear, you need to have an account. Ask your administrator to create one for you.</p>
<p>Log in with the username and password provided to you.</p>
<h2>Logging out</h2>
<p>To log out of IceBear, click the main menu icon at the top right of the page, then click "Log out [your username]" at the top left of the menu.</p>
<h2>Page header</h2>
<p>The page header contains a number of useful tools.</p>
<figure>
	<img alt="Header bar" src="headerbar.png" />
	<figcaption>The page header.</figcaption>
</figure>

<h3>Navigation breadcrumbs</h3> 
<p>On the left, there may be one or more buttons linking to useful pages. For example, when you view a project, you will see 
a link to the homepage and to a list of all projects.</p>
<h3>Find by barcode</h3>
<p>Type in this box to find items by their barcode. IceBear will suggest items as you type; you can use the up and down arrow
keys to move through the suggestions. press Enter to select the currently-highlighted suggestion.</p>
<p>If you have a barcode scanner, you can scan barcodes directly into this box.</p>
<h3>Main menu</h3>
<p>Click the main menu button at top right to open the menu. You will see something like this:</p>
<figure>
	<img alt="Main menu" src="mainmenu.png" />
	<figcaption>IceBear's main menu.</figcaption>
</figure>

<p>The exact options will depend on the application and on your permissions. Click any item to go there.</p>
<h3>Configuration</h3>
<p>Some pages, such as the homepage, can be configured to suit the way you work. These pages will have a gear wheel button 
next to the main menu button. Click this button to configure the page.</p>

<?php
include_once(dirname(__DIR__,3).'/client/help/_common/helpfoot.php');
?>
